@@ -14,7 +14,9 @@
 #' @keywords internal
 #'
 #' @examples
-#' \dontshow{.old_wd <- setwd(tempdir())}
+#' \dontshow{
+#' .old_wd <- setwd(tempdir())
+#' }
 #' write_union("a_file", letters[1:3])
 #' readLines("a_file")
 #' write_union("a_file", letters[1:5])
@@ -23,7 +25,6 @@
 #' write_over("another_file", letters[1:3])
 #' readLines("another_file")
 #' write_over("another_file", letters[1:3])
-#'
 #' \dontrun{
 #' ## will error if user isn't present to approve the overwrite
 #' write_over("another_file", letters[3:1])
@@ -31,7 +32,9 @@
 #'
 #' ## clean up
 #' file.remove("a_file", "another_file")
-#' \dontshow{setwd(.old_wd)}
+#' \dontshow{
+#' setwd(.old_wd)
+#' }
 NULL
 
 #' @describeIn write-this writes lines to a file, taking the union of what's
@@ -40,7 +43,9 @@ NULL
 #'   `.Rbuildignore` and `.gitignore`.
 #' @export
 write_union <- function(path, lines, quiet = FALSE) {
-  stopifnot(is.character(lines))
+  check_name(path)
+  check_character(lines)
+  check_bool(quiet)
   path <- user_path_prep(path)
 
   if (file_exists(path)) {
@@ -55,7 +60,7 @@ write_union <- function(path, lines, quiet = FALSE) {
   }
 
   if (!quiet) {
-    ui_done("Adding {ui_value(new)} to {ui_path(path)}")
+    ui_done("Adding {ui_value(new)} to {ui_path(proj_rel_path(path))}")
   }
 
   all <- c(existing_lines, new)
@@ -66,16 +71,21 @@ write_union <- function(path, lines, quiet = FALSE) {
 #'   necessary or overwriting existing, if proposed contents are not identical
 #'   and user is available to give permission.
 #' @param contents Character vector of lines.
+#' @param overwrite Force overwrite of existing file?
 #' @export
-write_over <- function(path, lines, quiet = FALSE) {
-  stopifnot(is.character(lines), length(lines) > 0)
+write_over <- function(path, lines, quiet = FALSE, overwrite = FALSE) {
+  check_name(path)
+  check_character(lines)
+  stopifnot(length(lines) > 0)
+  check_bool(quiet)
+  check_bool(overwrite)
   path <- user_path_prep(path)
 
   if (same_contents(path, lines)) {
     return(invisible(FALSE))
   }
 
-  if (can_overwrite(path)) {
+  if (overwrite || can_overwrite(path)) {
     if (!quiet) {
       ui_done("Writing {ui_path(path)}")
     }
@@ -93,16 +103,19 @@ read_utf8 <- function(path, n = -1L) {
 }
 
 write_utf8 <- function(path, lines, append = FALSE, line_ending = NULL) {
-  stopifnot(is.character(path))
-  stopifnot(is.character(lines))
+  check_name(path)
+  check_character(lines)
 
   file_mode <- if (append) "ab" else "wb"
   con <- file(path, open = file_mode, encoding = "utf-8")
-  on.exit(close(con), add = TRUE)
+  withr::defer(close(con))
 
   if (is.null(line_ending)) {
-    if (possibly_in_proj(path)) {
+    if (is_in_proj(path)) {              # path is in active project
       line_ending <- proj_line_ending()
+    } else if (possibly_in_proj(path)) { # path is some other project
+      line_ending <-
+        with_project(proj_find(path), proj_line_ending(), quiet = TRUE)
     } else {
       line_ending <- platform_line_ending()
     }
